:mod:`nilearn.regions`: Operating on Regions
============================================

.. automodule:: nilearn.regions
   :no-members:
   :no-inherited-members:

Classes
-------

.. currentmodule:: nilearn.regions

.. autosummary::
   :toctree: generated/
   :template: class.rst

   RegionExtractor
   Parcellations
   ReNA
   HierarchicalKMeans

.. autoclasstree:: nilearn.regions
   :full:



Functions
---------

.. currentmodule:: nilearn.regions

.. autosummary::
   :toctree: generated/
   :template: function.rst

   connected_regions
   connected_label_regions
   img_to_signals_labels
   signals_to_img_labels
   img_to_signals_maps
   signals_to_img_maps
   recursive_neighbor_agglomeration
